#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXgXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXjXlXlXlXlXlXlXlXlXlXlXlXlXkXhXgXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXCXDXAXcXjXlXlXlXlXlXlXlXlXlXlXlXjXMXDXSXmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXGXBXlXlXlXlXlXlXlXlXlXlXlXkXlXCXDXAXcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXhX`.L.~.tXMXjXlXlXlXlXlXlXlXlXlXzXmX%XI.Y.>XNXkXlXlXlXlXlXlXlXlXlXlXlXjXmX&XA. XlXlXlXlXlXlXlXlXlXlXkXbXkX[.L.!.rXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXiX]       M :XmXjXlXlXlXlXlXlXlXkXmXl.=     2 S.MXjXlXlXlXlXlXlXlXlXlXkXlXkXm   L lXlXkXlXlXlXlXlXlXkXcXdXX.      c %XMXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXm.  ! $X9.  $.BXjXlXlXlXlXlXlXkXbX*X  2 _.K.$ 4 uXxXkXlXlXlXlXlXlXlXlXgXAXS.    ( lXlXkXlXlXlXlXlXlXjXBXl.  R $Xq.  _ MXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX{.9.0XHXcX  I lXlXkXlXlXlXlXlXkXbX%X] W.AXUX}    XMXjXlXlXlXlXlXlXlXkXxXgXv 8   Q lXlXkXlXlXlXlXlXlXkXcXP.` 7XZXVX3 l yXcXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXHXzX6X>.  u.ZXhXlXlXlXlXlXlXlXkXnXIXBXdXCXI X >XbXjXlXlXlXlXlXlXlXjXNXH.  c.@ T lXlXkXlXlXlXlXlXlXlXkXCXIXxXzXiX$ C jXzXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXcX,X    Y zXzXkXlXlXlXlXlXlXlXlXkXfXdXAXK.  R NXjXlXlXlXlXlXlXlXlXlXcXu k 9X  R lXlXkXlXlXlXlXlXlXlXlXhXsXjXCX&.  k.SXgXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXkXtXe.k # I.NXhXlXlXlXlXlXlXlXlXlXhXBX X$ q 5XvXkXlXlXlXlXlXlXlXgXSXM.  D.VX  ! cXlXkXlXlXlXlXlXlXlXlXlXhXVXg.  ( zXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXVXAXzXHX7X% c sXxXkXlXlXlXlXlXlXlXhXMX,X5 # XXNXhXlXlXlXlXlXlXlXkXzXfXn 7 :XoX  F eXzXkXlXlXlXlXlXlXlXlXhXVXG.  n pXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXR.v.lXxXAXZ 3 5XnXkXlXlXlXlXlXlXjXbXeXg   Q.SXkXlXlXlXlXlXlXlXlXjXMX=X&       o   6.MXkXlXlXlXlXlXlXlXjXVX_.  u 0XNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX]   h.fXT.  C fXxXkXlXlXlXlXlXlXzXaXK   l.cXtXpXjXlXlXlXlXlXlXlXkXxXiXI.B.S.n.o v *XcXkXlXlXlXlXlXlXkXbX$X3 > .XzXtXsXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX;Xs       : W.BXhXlXlXlXlXlXlXjXNXU.          = OXmXjXlXlXlXlXlXlXkXxXSXFXKXbX  L MXlXkXlXlXlXlXlXlXkXMX&.    .     B aXxXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX7Xd.=.q.&XNXjXlXlXlXlXlXlXlXkXvX=X2.>.*.=.&.3.6XvXkXlXlXlXlXlXlXlXkXhXgXjXiX;.N.jXlXlXlXlXlXlXlXlXkXcXQ.=.>.&.;.@.j.gXzXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXGXLXJXnXjXlXlXlXlXlXlXlXlXlXkXnXKXLXLXLXPXKXvXkXlXlXlXlXlXlXlXlXlXlXlXlXzXLXAXlXlXlXlXlXlXlXlXlXlXkXVXPXKXLXLXIXFXzXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXfXjXlXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXfXfXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXhXlXlXlXlXlXlXlXlXlXlXlXhXfXfXfXfXfXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXzXlXkXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXxXzXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXhXlXlXlXlXlXlXlXlXlXlXlXkXnXcXzXzXvXbXkXlXlXlXlXlXlXlXlXlXlXkXzXbXgXjXlXlXlXlXlXlXlXlXlXlXlXlXzXnXxXzXzXbXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXS.  h 4XvXjXlXlXlXlXlXlXlXkXnX#XK . @ / 2XbXkXlXlXlXlXlXlXlXlXkXvXcX+.  *.AXhXlXlXlXlXlXlXlXlXlXkXbXP.d   , 2.sXxXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXsXc   0 2XbXjXlXlXlXlXlXlXkXxXtX7   } !   B xXkXlXlXlXlXlXlXlXkXxXtXE     } SXhXlXlXlXlXlXlXlXlXjXNX|.  > *.N   6.ZXhXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXB.    0 2XbXjXlXlXlXlXlXlXjXmX'.O <.GXAXL   %XmXjXlXlXlXlXlXlXjXVXL.0 q.* { SXhXlXlXlXlXlXlXlXlXkXMXI.u R.GXkX# B hXzXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX0 H c > 4XbXjXlXlXlXlXlXlXlXlXlXxXvXsXJX{   oXMXjXlXlXlXlXlXlXlXlXgXfX+X+ } DXhXlXlXlXlXlXlXlXlXlXlXzXvXvXBX{.  ! MXjXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXc.  R.I * 5XbXjXlXlXlXlXlXlXlXlXlXzXgXMX<X> u kXlXkXlXlXlXlXlXlXlXlXjXZX{.+ } DXhXlXlXlXlXlXlXlXlXlXlXlXcXtXR % p =XmXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXsXa y GXm ; 4XbXjXlXlXlXlXlXlXlXlXlXjXvXsXB   T.NXjXlXlXlXlXlXlXlXlXlXhXNX|.+ } DXhXlXlXlXlXlXlXlXlXlXlXkXcXeXd   u >XnXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXm.  E.UXN > qXbXjXlXlXlXlXlXlXlXlXkXzXzX~   f.BXjXlXlXlXlXlXlXlXlXlXlXhXBX|.+ } DXhXlXlXlXlXlXlXlXlXlXlXcXcXlXCX~.  G lXlXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXJ   i s *   ..jXlXkXlXlXlXlXlXlXkXlXmX%.  =.nXhXkXlXlXlXlXlXlXlXlXlXlXhXBX|.+ } DXhXlXlXlXlXlXlXlXlXlXlXrX9XxXgXGXL ; :XMXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkX7.B n M >   &.kXlXkXlXlXlXlXlXlXkXbXe.  $.GXSXCXcXlXlXlXlXlXlXlXlXlXlXhXBX|.@ | DXhXlXlXlXlXlXlXlXlXkXbX#.  ).JXiXu 8 6XnXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXZXHXFXUXM & uXnXjXlXlXlXlXlXlXkXmX{.    U ) R { 1XvXkXlXlXlXlXlXlXlXlXhXBX{.  ' DXhXlXlXlXlXlXlXlXlXjXMX~.  , ^ j   >.NXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXsXNXE d 6XvXkXlXlXlXlXlXlXjXMX^.e 9 = * # 8 #XnXjXlXlXlXlXlXlXlXlXjXNXOXr :.AXhXlXlXlXlXlXlXlXlXlXlXnXR.N = r y.gXcXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXnXzXlXlXlXlXlXlXlXlXlXlXcXmXnXNXBXVXBXxXlXlXlXlXlXlXlXlXlXlXlXlXzXnXvXlXlXlXlXlXlXlXlXlXlXlXlXlXmXNXBXNXMXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXSXAXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXAXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXK.c.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.m.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.n.b.n.b.b.b.b.b.b.b.b.b.b.b.b.b.n.n.b.n.b.b.b.b.b.b.b.b.b.b.b.b.n.b.m.dXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX} B S C C C C C C C C C C C C C C C S Z C C C C C C C C C C C C C C C Z K P L L L L L L L L L L L L L P L G P L L L L L L L L L L L L L L L J uXcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX-.U ..$.@.@.@.@.@.@.@.@.@.@.@.@.@.#.` +.#.@.@.@.@.@.@.@.@.@.@.@.@.@.#.X.C v n b b b b b b b b b b b b v N I c n b b b b b b b b b b b b n x Y aXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXbXbXbXvXlXlXlXlXlXlXlXjXMX*.G 5.k.d.f.f.f.f.f.f.f.f.f.f.f.d.j...i.g.f.f.f.f.f.f.f.f.f.f.f.f.d.j.8.;                               o v                                 n gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX@X5 %   o   A AXhXlXlXlXlXlXjXMX*.H 1.s.y.u.u.u.u.u.u.u.u.u.u.u.y.a.| e.i.u.u.u.u.u.u.u.u.u.u.u.u.y.a.4.3   o X X X X X X X X X X X X   * m   o X X X X X X X X X X X X o   N fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXOX  i ..} ) i.NXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX$X  7.UXUXLXNXkXlXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX@X  W K.Z.*XnXkXlXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXXX        < R.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX$X; N @XR.X i jXlXkXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX-XeXbXPX~ . oXMXjXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXbXdXHX..  `.BXhXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX{.; 9.SXcXz $ 3XbXjXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXuXr   ! C    .BXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX:XQ % , :.pXxXkXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXmXnXnXmXxXkXlXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXkXkXlXlXlXlXlXlXlXjXMX*.H 1.s.y.u.u.u.u.u.u.u.u.u.u.u.y.a.| e.i.u.u.u.u.u.u.u.u.u.u.u.u.y.a.4.3   o X X X X X X X X X X X X   * m   o X X X X X X X X X X X X o   N fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX*.H 4.j.s.s.s.s.s.s.s.s.s.s.s.s.s.h. .u.f.s.s.s.s.s.s.s.s.s.s.s.s.a.g.8.;                               o v                                 n gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX*.K $.2.,.,.,.,.,.,.,.,.,.,.,.,.,.1.' :.<.,.,.,.,.,.,.,.,.,.,.,.,.,.1.$.c s g f f f f f f f f f f f f d k H a g f f f f f f f f f f f f g p K aXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXfXgXlXlXlXlXlXlXlXjXMX%.E u % ; - - - - - - - - - - - ; & C < = ; - - - - - - - - - - - : # g z 2 8 7 7 7 7 7 7 7 7 7 7 7 8 6 r A 4 8 7 7 7 7 7 7 7 7 7 7 7 7 9 2 D sXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXKXLXPXPXIXFXkXlXlXlXlXlXlXjXMX$.Q 6                               m o                               y 0                               O v                                 n gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX3X@. .{ | ) y.NXjXlXlXlXlXlXjXMX$.W 9   X . . . . . . . . . . . X   M #   . . . . . . . . . . . . X   i r   X . . . . . . . . . . . .   & n   X . . . . . . . . . . . . o   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX X    @ @   F AXhXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX$X  -.MXgXfXgXlXlXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX#X  -.nXdXbXbXkXlXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXOXO &     Q 7XvXkXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXXX  $ *.(   T MXjXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXqXi.W.SXFXB @ >XnXjXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXUXSXuXGXX.  `.BXhXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX%X .(.AXJXT X #XMXjXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX:X  3 T.k.  x cXkXkXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXN.>     d .XnXkXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXMX,X(._.qXMXkXlXlXlXlXlXlXjXMX$.W 9   .                       .   M @                           .   i e   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXAXZXvXjXlXlXlXlXlXlXlXjXMX$.W 9   X                       .   M @                           X   i r   X                       .   & n   X                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXkXlXlXlXlXlXlXlXlXjXMX$.Q 6                               m #   . . . . . . . . . . . . X   p q                               @ n   X . . . . . . . . . . . . o   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX%.E p & > : : : : : : : : : : : > = V                                 e g % > : : : : : : : : : : : : - 6 b                                 n gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXkXlXlXlXlXlXlXlXlXjXMX%.Y Z z c c c c c c c c c c c c v l T M.M.M.M.M.M.M.M.M.M.M.M.M.M.m.Z.w.b c c c c c c c c c c c c c c v l O.A.n.M.M.M.M.M.M.M.M.M.M.M.M.m.Z.#.eXvXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXNXCXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXCXcXkXlXlXlXlXlXlXlXjXMX$.Q 4                               J UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX2X.                                 f.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXl.4XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXMX&X{.pXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMX*X{.iXxXkXlXlXlXlXlXlXjXMX$.W 0   o X X X X X X X X X X X o   K KXLXKXKXKXKXKXKXKXKXKXKXKXKXGXUX#X%   o X X X X X X X X X X X X o   u.UXGXKXKXKXKXKXKXKXKXKXKXKXKXGXUXd.6XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXCXN.    }.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXS.    _.CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXkXbXy.  1 & .XBXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXf.  < $ ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXcX$.r.=.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvX-.0.<.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXxXmXAX$.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnXSX:.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXhXmX@.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNX-.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXMX@.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX-.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXNX@.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX-.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXNX@.  XXVXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX-.  ].CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXMX%.X oXBXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX:.  [.CXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXNX[   }.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXo.  ).ZXhXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXbXM.( <XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXC./ ;XmXjXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXCXKXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXKXbXkXlXlXlXlXlXlXlXjXMX$.W 9   .                       X   K UXUXUXUXUXUXUXUXUXUXUXUXUXUXLXUX&X$   .                         .   i.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUXf.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXhXfXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXkXlXlXlXlXlXlXlXlXjXMX$.W 9   o . . . . . . . . . . . o   K PXPXLXLXLXLXLXLXLXLXLXLXLXLXHXUX$X%   X . . . . . . . . . . . . X   u.UXHXLXLXLXLXLXLXLXLXLXLXLXLXHXUXd.5XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX$.Q 4                               J UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX,XO                                 d.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXk.4XnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX&.U L A D D D D D D D D D D D D D A E 0.0.0.0.0.0.0.0.0.0.0.0.0.0.9.e.-.V m M M M M M M M M M M M M M M m ] 6.2.3.3.3.3.3.3.3.3.3.3.3.3.2.5.{ tXcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXjXMX*.H 4.h.a.s.s.s.s.s.s.s.s.s.s.s.s.h.| 3.8.7.7.7.7.7.7.7.7.7.7.7.7.6.9.>.6 . # + + + + + + + + + + + @ o : v                                 b gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXMXMXxXlXlXlXlXlXlXlXjXMX*.H 2.s.u.u.u.u.u.u.u.u.u.u.u.u.u.a.| y.s.a.a.a.a.a.a.a.a.a.a.a.a.p.f.7.<                               $ m   o X X X X X X X X X X X X o   N fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX9Xl 8 W.mXkXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX7.    F.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX6X8     J.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSX>.= `   L.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX4X* [ m.  I.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX7.  <Xx.  P.MXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX7X# | UXv.  !.VXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXh.  p T i   A 6XvXkXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXN.s e 8 ,   a ,XbXjXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXCXBXUXv.  ~.VXjXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXdXZXk.  Y.mXkXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXsXjXlXlXlXlXlXlXlXjXMX*.H 2.d.u.i.i.i.i.i.i.i.i.i.i.i.u.s.| r.p.i.i.i.i.i.i.i.i.i.i.i.i.u.s.5.2   .                           & n   .                         X   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXzXlXlXlXlXlXlXlXjXMX*.H 1.s.y.u.u.u.u.u.u.u.u.u.u.u.y.a.| e.i.u.u.u.u.u.u.u.u.u.u.u.u.y.a.4.3   o . . . . . . . . . . . X   * m   o . . . . . . . . . . . . o   M fXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX;.L 8.x.g.h.h.h.h.h.h.h.h.h.h.h.h.z.o.s.j.h.h.h.h.h.h.h.h.h.h.h.h.g.l.q.<                               # m                                 N gXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX .m ` +.X.X.X.X.X.X.X.X.X.X.X.X.X.O.Y  .o.X.X.X.X.X.X.X.X.X.X.X.X.X.O.' 0 ; , , , , , , , , , , , , , : 4 x - , , , , , , , , , , , , , < = v aXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX@X{.[.`.'.'.'.'.'.'.'.'.'.'.'.'.'.`.{.'.`.'.'.'.'.'.'.'.'.'.'.'.'.'.`.].OX@X+X@X@X@X@X@X@X@X@X@X@X@X@X@X+X.X@X+X@X@X@X@X@X@X@X@X@X@X@X@X+X@X.XgXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXVXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXBXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXBXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXBXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXkXlXlXlXlXlXlXlXlXlXkXhXgXhXlXlXlXlXlXlXlXlXlXlXlXlXgXgXlXlXlXlXlXlXlXlXlXlXhXgXhXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXLXGXcXkXlXlXlXlXlXlXlXkXzXDXLXCXkXlXlXlXlXlXlXlXlXlXlXkXDXDXzXlXlXlXlXlXlXlXlXkXCXLXDXzXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMX`.3.g.eXbXkXlXlXlXlXlXkXvXgXn.1.T.vXlXlXlXlXlXlXlXlXlXlXxXx.z.gXzXlXlXlXlXlXlXlXnXE.1.b.sXvXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCXb.  p & c sXxXkXlXlXlXlXlXlXA . g   w.CXhXlXlXlXlXlXlXhXVX).  2 uXcXkXlXlXlXlXjXVX4.  g X L xXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX7.o.UX#X  `.BXjXlXlXlXkXnX1Xy I.UX} 6 hXxXkXlXlXlXlXlXkXnXI   h uXxXkXlXlXlXkXzXzXH -.UXJ.  @XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXVX8X-.6 6XbXkXlXlXlXlXlXzXVXzXKX$.q lXzXkXlXlXlXlXhXCXY.7 ] 7 aXxXkXlXlXlXlXlXkXMXbXSXQ.  *XmXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXbXZ   q.SXhXlXlXlXlXlXlXlXdXVX.X  i.AXhXlXlXlXlXkXkXBXk -.g.> sXxXkXlXlXlXlXlXlXgXxXdX0 K NXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXbX8X2.* %XmXjXlXlXlXlXlXhXMX3X% Q mXkXlXlXlXlXlXjXCXY.= jXa.< hXxXkXlXlXlXlXlXkXxXcXB 6 eXvXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX[.2XUXcX- u.DXhXlXlXlXlXjXnXuXr C BXNXkXlXlXlXlXlXjXCX'   u :   a.BXjXlXlXlXlXkXlXNX_ - 7XFXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXnXx 7 -Xp.  E.VXjXlXlXlXkXzXhXB & |.-X;XkXlXlXlXlXlXkXcX Xx.V.Y + {.nXjXlXlXlXlXjXMX3.  n.4X@XsXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX#Xl . $ 2.vXlXlXlXlXlXjXmX+X@ @ %   x sXxXkXlXlXlXlXkXBXAXUXa.6 xXxXkXlXlXlXkXzXdXh   =   * +XmXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXkX6XrXMXzXlXlXlXlXlXlXzXhX9X5X5X6X0XkXlXlXlXlXlXlXlXjXgXjXyX8XjXlXlXlXlXlXlXlXkXeX6X5X6X7XgXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXzXnXvXjXlXlXlXlXlXlXlXlXzXnXnXnXnXbXlXlXlXlXlXlXlXlXlXlXlXcXbXlXlXlXlXlXlXlXlXlXbXnXnXnXnXzXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXkXkXkXkXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXkXlXlXlXlXlXlXlXlXlXjXjXjXjXkXlXlXlXlXlXlXlXlXlXkXjXjXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXBXbXlXlXlXlXlXlXlXlXkXmXCXCXCXvXkXlXlXlXlXlXlXlXkXzXVXMXzXlXlXlXlXlXlXlXlXkXvXCXCXCXmXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXOX0 4.mXkXlXlXlXlXlXjXMXoXC 5 ) 7XbXkXlXlXlXlXlXkXvXcX] x qXbXkXlXlXlXlXlXkXvXwX[ 6 m '.mXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX!   ` MXjXlXlXlXlXkXcXeX  k x.& I BXjXlXlXlXlXkXzXdXL   = 3XnXjXlXlXlXlXlXhXAXW   h.V < yXcXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX_.5 - _ NXkXlXlXlXlXkXvX9Xe.5XUX9.< sXcXkXlXlXlXkXcXqXl.f., 5XnXkXlXlXlXlXlXlXxXI.{.UX^.  ;XmXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXV { J I BXkXlXlXlXlXlXkXvXHXxXBXZ n NXkXlXlXlXlXlXkXlXUXC.* 6XnXkXlXlXlXlXlXlXkXZXNXr.5 } bXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCX`.# uXD E AXjXlXlXlXlXlXlXkXsXAXq.  [.BXjXlXlXlXlXlXlXhXVXM.* 6XnXkXlXlXlXlXlXlXlXdXgXE   2.BXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXF j 2Xa V gXzXkXlXlXlXlXlXhXSXm.  n.VXhXlXlXlXlXlXlXlXhXAXN.* 6XnXkXlXlXlXlXlXlXzXDXmXGXJ.  {.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXsXN O $ o o /.NXjXlXlXlXlXjXBX!.+ c.UXCXlXlXlXlXlXlXlXlXhXZXB.; 6XnXkXlXlXlXlXkXxXaX@.I.UX4XX A.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXaXrXmXa S NXkXlXlXlXlXkXvX5XX o 2.O.u.gXzXkXlXlXlXlXlXhXAXv.  4XmXjXlXlXlXlXkXkXnXS   ;.a 3 0XvXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXzXSX-.q.NXkXlXlXlXlXkXnX:XT G b h ' dXzXkXlXlXlXlXlXjXBX^.W wXvXkXlXlXlXlXlXkXvXsX3.c ^ %XmXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXjXZXVXkXlXlXlXlXlXlXkXvXDXFXJXKXDXzXlXlXlXlXlXlXlXlXkXnXDXxXlXlXlXlXlXlXlXlXkXcXSXJXGXnXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXlXlXlXlXlXlXlXlXkXgXgXgXgXhXlXlXlXlXlXlXlXlXlXlXkXgXlXlXlXlXlXlXlXlXlXlXkXhXgXhXjXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXmXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX7X*X:X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X-X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X*X;XjXzXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXgXgXhXlXlXlXlXlXhXZXt.V K G G G G G G G G G G G J H G G G G G G G G G G G F P E E E E E E E E E E E E T Y E E E E E E E E E E E R Q uXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXHXHXJXFXlXlXlXlXlXhXCXs.K =.-.=.=.=.=.=.=.=.=.=.;. .@.;.=.=.=.=.=.=.=.=.=.*.:.T i d s s s s s s s s s p c N i d s s s s s s s s d y J sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX(.k.j.f.m.jXzXlXlXlXhXCXp.J a.g.d.d.d.d.d.d.d.d.s.k.:.0.h.d.d.d.d.d.d.d.d.d.s.z.K                         : 0                         j hXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXS   w < z fXxXlXlXlXhXCXp.J t.i.u.u.u.u.u.u.u.u.y.s.=.6.a.u.u.u.u.u.u.u.u.u.y.f.L   o . . . . . . . . X   3 t   o . . . . . . . . o   x gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXF ~ UXUXBXkXlXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXU 8 ..:.7XbXkXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXK   P ; z hXzXkXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX[.~.UX|.  ).BXjXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXeXlXSX5Xo J.CXhXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXL i wX5.  >XnXkXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX|.r   O i.mXkXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXpX#X4XmXlXlXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.u.i.i.i.i.i.i.i.i.y.g.L   X                 .   2 r   X                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXBXmXjXlXlXlXlXlXhXCXp.J t.p.u.u.u.u.u.u.u.u.u.d.=.6.a.u.u.u.u.u.u.u.u.u.y.g.K                         < e                         l hXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXlXlXlXlXlXlXhXCXp.J p.f.s.s.s.s.s.s.s.s.a.j.;.9.g.s.s.s.s.s.s.s.s.s.a.k.U O = & & & & & & & & * @ 0 a + = & & & & & & & & = o n fXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXhXhXlXlXlXlXlXhXCXa.H v j k k k k k k k k k g Z n h k k k k k k k k k k k S s s s s s s s s s s d p c N i d s s s s s s s s d y H sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXFXGXHXFXlXlXlXlXlXhXCXa.G o                       e *                         f                         > q                         j hXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX7.g j p A fXxXlXlXlXhXCXa.G *   X X X X X X X X o   i <   X X X X X X X X X . o j   . . . . . . . . . X   3 t   o . . . . . . . . o   x gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXZ > r.,.e.hXzXlXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXF ! UXJXIXlXlXlXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXI   ; 4 G.MXjXlXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX] t E.^ O 8XvXkXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXzXJX3X  I.CXhXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXV.!.UX*X  W.VXjXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX'   e.k 4 iXxXkXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXdX>.e F @XmXjXlXlXlXhXCXa.G %                   .   u ,   .                   . h                     .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXZXSXSXnXkXlXlXlXlXhXCXa.G &   X . . . . . . . o   u <   X . . . . . . . . . X j   . . . . . . . . . X   3 t   o . . . . . . . . o   x gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXhXjXlXlXlXlXlXhXCXa.G o                       e ;                         f                         : w                         k hXzXkXlX",
"lXlXlXlXlXkXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXhXCXa.G a w r r r r r r r r r 0 n r < 3 3 3 3 3 3 3 3 3 3 3 N e r r r r r r r r r r q j j > 4 3 3 3 3 3 3 3 3 4 ; B fXxXkXlX",
"lXlXlXlXkXzXMXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXnXlXlXlXlXlXlXhXCXa.G 0 1 3 3 3 3 3 3 3 3 4 , h 9XzXgXhXhXhXhXhXhXhXhXfXnX .* 5 3 3 3 3 3 3 3 3 3 3 < ~.MXdXhXhXhXhXhXhXhXhXdXMXC.6XnXkXlX",
"lXlXlXkXbXzX>XaXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBX7X6XzXlXlXlXlXlXhXCXa.G +                       0 ZXUXUXUXUXUXUXUXUXUXUXUXUX .                          %XUXUXUXUXUXUXUXUXUXUXUXUXR.3XnXkXlX",
"lXlXkXxXdXI   T.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXS.  J BXjXlXlXlXlXhXCXa.G &   . . . . . . . . X   e bXUXLXPXPXPXPXPXPXPXPXKXUX .  O . . . . . . . . . .   OXUXJXPXPXPXPXPXPXPXPXJXUXI.4XnXkXlX",
"lXlXkXnX^ e = L.AXhXlXlXlXlXlXlXlXlXlXlXlXlXjXBXE.7 9 G BXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXkX%XXX- L.AXhXlXlXlXlXlXlXlXlXlXlXlXlXkXvX3X3X' N CXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXjXFX-X# P.AXhXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXGXE B CXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXjXnX&X$ P.AXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNXW B CXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXjXMX*X$ P.AXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXW B CXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXjXMX=X- I.AXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX~ Z VXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXjXNX$X  F.DXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXF f ZXjXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXkXcXrXz.<XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXE.K.bXkXlXlXlXlXhXCXa.G %                   .   e mXUXIXUXUXUXUXUXUXUXUXLXUX .  o                 .     +XUXLXUXUXUXUXUXUXUXUXLXUXU.3XnXkXlX",
"lXlXlXlXkXcXFXbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXAXkXlXlXlXlXlXhXCXa.G *   X X X X X X X X o   e bXUXLXPXPXPXPXPXPXPXPXJXUX .  o                 .     oXUXHXLXLXLXLXLXLXLXLXHXUXP.4XnXkXlX",
"lXlXlXlXlXkXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXlXlXlXlXlXlXhXCXa.G o                       9 SXUXUXUXUXUXUXUXUXUXUXUXUX..  X                       ;XUXUXUXUXUXUXUXUXUXUXUXUXQ.2XnXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXjXlXlXlXlXlXhXCXa.H I J J J J J J J J J K J I r.d.a.a.a.a.a.a.a.a.a.p.g.~ s j h h h h h h h h j g z O.,.:.:.:.:.:.:.:.:.:.:.>.o.yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXKXVXkXlXlXlXlXhXCXp.J d.j.g.g.g.g.g.g.g.g.f.z.>.,.w.9.0.0.0.0.0.0.0.0.8.y.K   o . . . . . . . . X   4 6                         f hXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX9X4.E.bXkXlXlXlXhXCXp.J t.i.y.u.u.u.u.u.u.u.y.s.*.8.f.p.a.a.a.a.a.a.a.a.i.j.L   .                     2 y   O o o o o o o o o +   x gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX>.  [ BXjXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX,X6   #.NXjXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX} A x ) VXjXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX1Xo `.N / CXjXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXAX .N UXh ` AXjXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXpX4   r X * .XMXjXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgXE.b.Z.7 n yXxXkXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXZXSXUXv ..FXhXlXlXlXhXCXp.J y.p.i.i.i.i.i.i.i.i.u.d.=.6.s.i.i.i.i.i.i.i.i.i.u.g.L   X                 .   2 r   .                 X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXhXwXtXlXlXlXlXlXhXCXp.J y.p.u.i.i.i.i.i.i.i.u.d.=.6.a.u.i.i.i.i.i.i.i.i.y.g.L   X . . . . . . . . .   2 r   X . . . . . . . . X   z gXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXcXlXlXlXlXlXhXCXs.P a.g.d.f.f.f.f.f.f.f.d.k.>.q.j.d.f.f.f.f.f.f.f.f.s.z.I   X                 .   3 y   X                 X   c hXzXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXhXZXq.n :.,.>.>.>.>.>.>.>.>.:.2.] @.1.>.>.>.>.>.>.>.>.>.:.4.B                         ; 7                         s fXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX.XF.P.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.L.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.L.U.fXzXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXAXCXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXZXCXzXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXkXjXlXlXlXlXlXlXlXlXjXkXkXjXkXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXjXkXkXjXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXVXmXNXNXlXlXlXlXlXlXlXkXMXBXmXVXcXkXlXlXlXlXlXlXlXkXvXnXxXlXlXlXlXlXlXlXlXNXNXmXVXzXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX8.8 i F.MXjXlXlXlXlXjXMX[.c 5 O.sXxXkXlXlXlXlXlXhXVX).1 N.VXjXlXlXlXlXjXMXJ.a 8 8.zXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX~.  M.4.@ 7XbXkXlXlXkXzXgX: T E.O w.AXhXlXlXlXlXlXkXmXD   p.ZXhXlXlXlXkXbX3X  -.V.  J.CXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXwX:XUX_.# 1XnXkXlXlXlXzXdX}.aXUXJ / SXjXlXlXlXlXhXZXK.t 6 e.AXhXlXlXlXlXxXyX}.cXUXt 9.SXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXHX3.  7.SXhXlXlXlXlXlXxXMXCX$Xo H.ZXhXlXlXlXlXkXNXg y.m 4.SXhXlXlXlXlXkXcXmXSXI.X +XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXBXoXQ k yXcXkXlXlXlXlXhXvXeX1 [ BXkXlXlXlXlXhXZXH.y DXf r.FXhXlXlXlXlXlXgXMX%XX e.CXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX,X*XUXnX* D.AXhXlXlXlXkXvXkXz U HXmXkXlXlXlXlXjXCXU   Z X l yXcXkXlXlXlXjXMX0X6 -.UXcXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXf.  R.t.X OXMXjXlXlXlXlXcXK + ).'.:XcXkXlXlXlXkXcX].x.b.- ! xXlXlXlXlXkXxXaXi q oX).6XcXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXhX*.3 q x.MXjXlXlXlXkXvX9Xg 9 0 $ 8.BXjXlXlXlXlXkXBXFXUXD x.DXhXlXlXlXjXMX@X8 e 7 * N.VXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXVXxXvXBXlXlXlXlXlXlXlXlXxXkXlXzXlXlXlXlXlXlXlXlXjXgXgXkXkXkXlXlXlXlXlXlXlXzXkXlXzXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXzXlXjXlXlXlXlXlXlXlXlXzXzXzXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzXzXzXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXjXlXlXlXlXlXlXlXlXkXgXgXjXlXlXlXlXlXlXlXlXlXlXgXhXlXlXlXlXlXlXlXlXlXkXgXgXjXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXGXVXkXlXlXlXlXlXlXkXzXDXLXNXkXlXlXlXlXlXlXlXkXkXFXCXkXlXlXlXlXlXlXlXkXxXGXKXmXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXdXs.~.bXkXlXlXlXlXkXcXkXM.5.|.mXkXlXlXlXlXlXkXvXMXv.Y.mXkXlXlXlXlXlXkXbXiXh.8.&XmXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXAXn.  [ CXjXlXlXlXlXkXbXF * N O Q.BXjXlXlXlXkXzXgX|   R SXhXlXlXlXlXkXzXkXj 1 x , &XmXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXaXz   #.VXjXlXlXlXkXcXiX_ {.UXm ) SXjXlXlXlXkXmX=X;.U ~ SXhXlXlXlXlXkXcXrX*.0XUX$ s.DXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXe.N I ^ ZXjXlXlXlXlXlXzXFXmXnXr 3.DXhXlXlXlXlXkXzXUX` Y DXhXlXlXlXlXlXlXlXLX3X( a <XnXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXdXw oX] ) GXhXlXlXlXlXlXkXdXAX..6 yXvXkXlXlXlXlXlXhXCX/ T DXhXlXlXlXlXlXlXhXnX^.& x dXxXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXa.  I.g M fXzXkXlXlXlXlXjXFX0.. $XNXjXlXlXlXlXlXlXjXAX( T DXhXlXlXlXlXlXlXxXNXVXnXr 3.SXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXl.f j = 4 ;XnXjXlXlXlXjXBXV.& .XUXcXlXlXlXlXlXlXlXjXAX_ E DXhXlXlXlXlXjXMXOXn ,XGXd O.DXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXMXUXZ E HXhXlXlXlXkXcXrX@   B 0 i.NXjXlXlXlXlXlXhXSXU S FXhXlXlXlXlXkXxXaXb , e 5 &XmXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXcX_.{.vXkXlXlXlXlXxXaXY.C.v.l.|.vXkXlXlXlXlXlXkXbX}.].bXkXlXlXlXlXlXkXbXjXK.M.6XMXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXBXkXlXlXlXlXlXlXxXAXFXGXHXBXkXlXlXlXlXlXlXlXkXBXVXkXlXlXlXlXlXlXlXkXzXSXGXbXjXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXhXhXhXgXjXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXCXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXVXCXBXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX].Q.^.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.!.!.!.!.!.!.!.!.!.!.!.~.~.!.!.!.!.!.!.!.!.!.~.W.[.zXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXjXjXkXlXlXlXlXlXcX[ V F D D D D D D D D D D F D D D D D D D D D D D F J J J J J J J J J J J J H J J J J J J J J J K A } cXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXCXCXZXbXkXlXlXlXlXcX@.] y.q.w.w.w.w.w.w.w.e.8.%.r.q.w.w.w.w.w.w.w.q.y.+.> > > > > > > > > > - 0 h * , > > > > > > > < @ / mXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX) w i 2 J.AXhXlXlXlXcXo.] h.p.a.a.a.a.a.a.a.s.t.*.f.p.a.a.a.a.a.a.a.p.j.#.                      = e                       T NXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzX6 ' [.C.:XnXkXlXlXlXcXo.] d.u.i.i.i.i.i.i.u.p.e.&.a.u.i.i.i.i.i.i.i.y.f.@..   . . . . . . . .   : t   X . . . . . . . o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXa 1.%XsXZXjXlXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXkXq   3 < +XMXjXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXx.R.DXj _ SXjXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXuXmXUXo.A BXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXxXa ( &X- <.SXhXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX~.i * E yXcXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXxXaXmXvXkXlXlXlXlXcXo.' d.y.u.u.u.u.u.u.u.i.w.&.a.y.u.u.u.u.u.u.u.y.d.@.. . X . . . . . . X   : t   X . . . . . . . O   E MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXzXcXkXkXlXlXlXlXlXcXo.[ l.d.f.f.f.f.f.f.d.g.i.-.j.d.f.f.f.f.f.f.f.s.l.$.                      & q                       Y NXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXgXgXkXlXlXlXlXlXcXO.~ :.*.=.=.=.=.=.=.=.-.%.} ;.=.=.=.=.=.=.=.=.*.:.[ t t t t t t t t t t e f b w y t t t t t t t u 6 ` nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXZXJXJXKXmXkXlXlXlXlXzX*.x   O o o o o o o o X & s   O o o o o o o o O   p 6 * ; ; ; ; ; ; ; ; * 8 d % : ; ; ; ; ; ; ; > o ~ mXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXI.d.d.r.%XmXjXlXlXlXzX*.l                     @ p                       y $                     = w                       T NXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXkX8 = C u U.ZXhXlXlXlXzX*.z   X             .   # a   .               X   u *   .             .   : t   X               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXxXy C.UXUXmXjXlXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXkXu = e o.dXxXkXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXD E J.+ w.SXhXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXNXUX| S VXkXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXhXO.E.UXN Q AXjXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX} O k & `.BXjXlXlXlXzX*.z   .                 # p   .               .   u *                     : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXbXU.y.$XMXkXlXlXlXlXzX*.z   X                 # a   .               X   u *   .             .   : t   X               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXAXKXMXjXlXlXlXlXlXzX*.l                     O a   o X X X X X X X o   i $                     = t   o X X X X X X X +   E MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXjXlXlXlXlXlXlXzX&.v $ = * * * * * * = & 1 u                       e 4 % = * * * * * * = $ 7 9                       U NXjXlXlX",
"lXlXlXlXjXzXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXxXzXlXlXlXlXlXlXxX%.C t u u u u u u u u i 0 >.^.I.Y.Y.Y.Y.Y.Y.Y.I.^.7.w i u u u u u u u u u r y.~.I.Y.Y.Y.Y.Y.Y.Y.U.Y.p.hXzXlXlX",
"lXlXlXkXMXlXfXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXNXfXjXlXlXlXlXlXlXzX=.k                       N.UXUXUXUXUXUXUXUXUXUXUXW.                        XXUXUXUXUXUXUXUXUXUXUXUXT.iXcXlXlX",
"lXlXjXNX}.> @.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXkXMX9.@ /.CXhXlXlXlXlXzX*.z   X . . . . . . . O   x.UXGXKXKXKXKXKXKXKXGXUXK.  o . . . . . . . X X   ).UXGXKXKXKXKXKXKXKXJXUXK.pXxXlXlX",
"lXkXnX:Xj : ( SXhXlXlXlXlXlXlXlXlXlXlXlXhXCXj.q & P.AXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXcXeX9X[ E DXhXlXlXlXlXlXlXlXlXlXlXlXkXcX4X-X0 L.AXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXkXzXJX! E DXhXlXlXlXlXlXlXlXlXlXlXlXlXjXVXrX1 P.AXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXlXhXCX~ E DXhXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X3 P.AXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXlXjXZX/ Q DXhXlXlXlXlXlXlXlXlXlXlXlXlXkXbXqX5 I.AXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXlXjXAXY L FXhXlXlXlXlXlXlXlXlXlXlXlXlXkXbX0X* J.SXhXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXlXjXVX>.-.ZXjXlXlXlXlXlXlXlXlXlXlXlXlXkXvXrXS (.VXjXlXlXlXlXzX*.z   .               o   c.UXKXUXUXUXUXUXUXUXKXUXP.  X                 .   `.UXLXUXUXUXUXUXUXUXPXUXL.pXxXlXlX",
"lXlXlXlXkXnXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXMXcXkXlXlXlXlXlXzX*.z   o X X X X X X X O   x.UXGXLXLXLXLXLXLXLXGXUXL.  o . . . . . . . . X   ).UXGXKXKXKXKXKXKXKXHXUXK.pXxXlXlX",
"lXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXzX=.j                       M.UXUXUXUXUXUXUXUXUXUXUXE.                        XXUXUXUXUXUXUXUXUXUXUXUXT.iXcXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXkXlXlXlXlXlXxX$.F b n n n n n n n n m l -.K.Z.S.S.S.S.S.S.S.Z.K.2.y a a a a a a a a a a p 1.n.k.z.z.z.z.z.z.z.z.l.q.kXzXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXHXxXlXlXlXlXlXcXX.{ z.f.f.f.f.f.f.f.f.g.a.+.6.4.4.4.4.4.4.4.4.3.8. .# @ # @ @ @ @ @ @ # o 3 7                       I NXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXK.>.rXcXkXlXlXlXcXo.' d.y.u.u.u.u.u.u.u.i.w.=.g.a.s.s.s.s.s.s.s.a.k.$.                      - y   O o o o o o o o +   E MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXuX*   >XnXjXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                  .   : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDX0.& 6 >XnXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXqX9 8.2 -XnXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXFX>./ 7X$ 8XnXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXtX# ~ <.  S.MXjXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX8X` S z   w.NXjXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXZXUX-X  7XnXkXlXlXlXcXo.] f.u.i.i.i.i.i.i.i.p.e.&.s.u.i.i.i.i.i.i.i.u.f.@.                      : r   .               o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXjXrX`.aXxXlXlXlXlXcXo.] d.u.u.u.u.u.u.u.u.p.e.&.a.u.u.u.u.u.u.u.u.y.f.@..   . . . . . . . .   : t   X . . . . . . . o   R MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXCXxXlXlXlXlXlXcX+.} l.d.f.f.f.f.f.f.f.g.i.;.j.d.f.f.f.f.f.f.f.d.l.&.                      : t   .               X   E NXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXlXlXlXlXlXlXcX' Y 1.;.:.:.:.:.:.:.:.>.*.' ,.;.:.:.:.:.:.:.:.;.1.) o X o X X X X X X o   ; q   o X X X X X X X +   P MXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXXX_.`._._._._._._._._._.`.`._._._._._._._._._._._.`.{.{.{.{.{.{.{.{.{.{.{.[.[.{.{.{.{.{.{.{.{.{.{.].oXzXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXVXNXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXjXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXjXhXlXlXlXlXlXlXhXhXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXDXDXNXkXlXlXlXkXmXFXDXvXkXlXlXlXlXjXmXAXlXlXlXlXlXxXSXFXNXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXfX3.I (.MXjXlXkXnX=X)  .9XvXkXlXlXhXCXQ.O.zXlXlXlXzXgX7.I !.MXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXoX%.I.g zXlXlXhXZX6.s.:...GXhXlXlXkXmXk 3 lXzXkXjXBX[._ U.h sXxXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXmXT *.ZXhXlXlXkXlXUX;.3.FXhXlXhXDXG.W W dXzXlXlXlXhXUX@XN zXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXCXd.~ kXzXlXlXhXJXM.F cXzXkXlXzXjXm d.N wXcXkXlXjXBX0Xl  XVXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXW.1.>Xu wXvXkXjXBXY.6 .XaXlXlXkXvXwX} I @ #XMXjXkXcXuXs w.fXgXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXeX .V S.NXjXlXjXVX6.V I c.BXjXlXlXzXHXaX%.kXzXlXjXBX[.c Q ..fXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXAXMXBXkXlXlXlXkXMXMXvXvXlXlXlXlXlXhXjXmXlXlXlXlXkXcXVXvXbXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXlXlXlXlXlXlXlXhXxXxXjXlXlXlXlXlXjXzXlXlXlXlXlXlXjXjXvXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXhXsXzXlXlXlXkXVXuXuXMXkXlXlXlXkXVXgXfXzXlXlXlXkXbXzX7XmXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXl 5.DXhXlXjXVXZ.l N (.NXjXlXjXmX`.4 Y.ZXhXlXkXvX0XG m 5.mXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXL.  5.SXhXlXjXNXV.2Xb.Q HXhXlXkXvX^.M Z.DXhXlXkXnX,XU.#Xk gXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfXO.1.4.HXgXlXlXjXAXDXS Z.AXhXlXlXgXUX+.M.FXhXlXlXjXBXVXp ;.DXhXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXB.p ~ Y MXkXlXlXkXZX+.q.UXhXlXlXlXhXAX .B.DXhXlXlXxXrXgXrXM 0XbXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX=XA.F H BXjXlXhXSX7.# b.[.bXkXlXlXhXGX^ x.GXhXlXjXVX(.N t.n iXcXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXUX;X'.BXjXlXkXnXI.r.,.E.mXjXlXlXkXmXQ.%XmXkXlXlXkXbXI.<.;XmXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXbXNXjXlXlXlXkXCXHXKXVXkXlXlXlXlXkXVXnXkXlXlXlXlXkXZXKXnXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXjXkXlXlXlXlXlXlXhXgXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXcXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXbXbXbXbXbXbXbXnXnXbXbXbXbXbXbXbXbXzXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXbXvXlXlXjXNX}.&.<.,.,.,.,.,.>.<.,.>.,.,.,.,.,.>.2.7.6.7.7.7.6.7.6.5.7.6.7.7.7.7.5.0.pXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXyX4X0XlXlXhXCXP.L ,.*.=.=.=.=.;...#.-.=.=.=.=.*.<.D & , > > > > ; 5 e - > > > > , & f pXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX,Xg Q @.lXlXhXCXY._ z.d.f.f.f.d.j.6.y.h.f.f.f.f.s.v.L               $ 3               e dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX#Xh ).aXvXkXjXCXU./ f.u.u.u.u.u.a.2.q.p.u.u.u.u.t.h.K   o . . . .   = 5   X . . . o   y sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX<Xa H R kXlXhXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXiX0XUXb OXNXgXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX6XJ 3.n yXcXhXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX^.;.$XMXjXhXCXU./ d.t.y.y.y.y.p.1.0.i.y.y.y.y.r.g.J   X           & 4   .       .   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXGXbXkXlXhXCXU._ b.h.j.j.j.h.z.8.p.l.j.j.j.j.g.m.I   o . . . X   = 5   X . . . o   y sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXCXAXZXlXlXhXVXW.A F D D D D D S J G S D D D D S G B 7 0 9 9 9 0 8 y g 7 0 9 9 9 q 4 b aXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXsXP.l.J.zXlXhXBX^.p               , X               7               & 3           .   r dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX%Xw y.k.kXlXhXBX^.d   o X X X o   6 *   X X X X X X 0           .   * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX$Xq w.-XMXjXjXBX^.d   .       .   5 &               0               * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX8X#.r.l eXvXhXBX^.d   .       .   5 &               0               * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXwX@XUXv +XNXgXBX^.d   .       .   5 &               0               * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXrXZ M ) xXlXhXBX^.d   X       .   5 &   .         . 0   .       .   * 5   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXaX[.hXcXkXhXBX^.s               3 &   . . . .   . 9               $ 4   . . . . X   t dXxXkXlX",
"lXlXlXlXkXgXlXlXlXlXlXlXlXlXlXlXkXzXMXlXkXlXhXBX~.j * - = = = - % w +               w - = = = = = & 4 3               e dXxXkXlX",
"lXlXlXkXmXFXxXlXlXlXlXlXlXlXlXlXkXnXDXxXlXlXhXVX!.l 2 4 3 3 3 4 : v =X:X;X;X;X;X=X7Xo.& 6 3 3 3 3 4 , S.5X=X;X;X;X-X2XY.8XbXkXlX",
"lXlXkXnX&Xo.qXvXkXlXlXlXlXlXlXkXnX=Xo.9XbXkXhXBX^.a               s UXUXUXUXUXUXUXUX>.                -XUXUXUXUXUXUXUX8X4XnXkXlX",
"lXlXlXzX-.> =XMXjXlXlXlXlXlXlXlXxX>.: %XNXjXhXBX^.d   X . . . o   f GXIXLXLXLXLXHXUX-.  O . . . . X   OXUXHXLXLXLXJXUX>X5XnXkXlX",
"lXlXlXkXxXU #XNXjXlXlXlXlXlXlXlXjXcXY OXBXjXhXBX^.d   .       X   d KXUXIXUXUXUXKXUX-.  O         .   @XUXLXUXUXUXPXUX<X4XnXkXlX",
"lXlXlXlXxXG $XNXjXlXlXlXlXlXlXlXlXvXH +XBXjXhXBX^.d   .       X   d KXUXIXUXUXUXKXUX-.  O         .   @XUXLXUXUXUXPXUX<X4XnXkXlX",
"lXlXlXlXxXN @XNXjXlXlXlXlXlXlXlXlXcXV XXBXjXhXBX^.d   .       X   d KXUXIXUXUXUXKXUX-.  O         .   @XUXLXUXUXUXPXUX<X4XnXkXlX",
"lXlXlXlXzXO.:XmXkXlXlXlXlXlXlXlXlXcX+.-XMXkXhXBX^.d   o . . . o   f GXIXLXLXLXLXHXUX-.  O . . . . X   OXUXHXLXLXLXJXUX>X5XnXkXlX",
"lXlXlXlXlXbXzXlXlXlXlXlXlXlXlXlXlXlXvXzXlXlXhXBX^.p               p UXUXUXUXUXUXUXUX>.                :XUXUXUXUXUXUXUX9X3XnXkXlX",
"lXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlXkXzXlXlXhXVX!.v r t r r r y 9 B OX$X#X#X#X#X+X<XX.- 8 5 5 5 5 6 2 b.@X[.}.}.}.{.oXD.9XbXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXgXlXlXhXCXU.( k.a.s.s.s.a.g.3.:.4.2.2.2.2.1.9.H o * % % % & # 2 ,               9 dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX_ ` ZXjXhXCXU./ f.u.u.u.u.u.a.2.t.f.s.d.d.d.a.x.K               $ 5   o X X X O   y sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX%X+ ^ VXjXhXCXU./ g.u.i.i.i.u.a.2.q.p.i.i.i.i.y.j.K   X       .   * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX:.1.X.AXhXhXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX|.w +.n jXzXhXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX3Xv.^ u jXzXhXCXU./ g.u.i.i.i.u.s.2.q.a.i.i.i.i.y.j.K   X           * 4   .       X   t dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXUX0XK.BXjXjXCXY._ j.p.a.a.a.p.d.4.e.s.p.a.a.a.i.l.P   + o o o O . ; 7   O o o o +   i dXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXxXVXjXlXhXZXK.U u.0.q.q.q.0.r.=.4.e.q.q.q.q.9.a.B                 %               2 sXxXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXlXlXjXMXoXt.M.b.n.n.n.b.n.z.v.n.n.n.n.n.b.M.t.*.;.-.-.-.-.=.>.2.=.-.-.-.-.;.&.8.dXxXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXBXmXmXmXmXmXmXmXMXMXmXmXmXmXmXmXmXVXDXSXSXSXSXSXSXAXAXSXSXSXSXSXSXSXZXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXgXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXlXkXlXlXkXlXzXkXlXlXlXlXkXlXlXlXlXkXxXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXgXkXvXkXkXcXxXgXnXkXlXlXzXbXlXlXlXlXmXsXnXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX8X$.:.tXcXzXfX;. .:XmXjXlXbXY {.BXgXVXA.~ A.NXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgX XR wXvXzXyXsX2.H.SXfXVX].h {.VXhXlXwX`. .ZXhXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXsXqX .-XMXgXZX_.7.BXjXkXzX[ S F.AXhXxXhX&.4XmXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX-X+.#.3XbXzXsXn =.4XbXkXhX&X .J.ZXfXSX4.B ).vXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX8XwXnXkXzXhX9X=XiXxXkXlXVXlXjXzXlXzXtX,X4XxXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXSXjXlXlXxXFXGXnXkXlXkXnXCXlXlXlXkXCXFXZXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMX-X;.cXkXlXkX0.>.wXvXjXMX'.2.vXlXjXNX/.+.~.MXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX8.n bXkXxXeX#X>.Z.DXgXmX(.E lXlXkXvX-X7.<.SXhXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXOXU } yXcXhXVXqX2.jXzXkXzXlX-.gXzXlXhXGXG.4.CXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX2Xp.C eXcXlXhXv <.tXcXkXxXuXo.hXzXjXBXx.>.1.MXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXSX6XlXlXzXdX}.!.0XvXkXlXjX1XkXlXkXcXyXW.aXcXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXbXlXlXlXzXVXZXvXkXlXlXlXnXlXlXlXkXcXZXxXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXhXjXjXjXjXgXgXhXjXjXjXjXgXjXjXjXjXhXfXhXjXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXhXkXlXkXvXBXNXNXNXNXNXNXNXNXNXNXNXBXBXBXBXBXBXBXBXBXBXBXBXMXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXZXDXcXjXMXXX9.i.y.y.y.y.y.y.y.y.y.u.y.t.t.t.t.t.t.t.t.t.y.q.c.lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXK.c.7XxXCXJ.) 7.1.1.3.:.&.3.1.1.<.8.h   X       , .     X   b bXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXcXyXx g.sXkXVXU.&.l.s.d.f.y.q.g.s.d.a.x.v   X       2 .     X   M nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXxXsXi.:.(.MXBXI.@.g.u.u.p.w.7.a.u.i.y.h.c   X . .   2 .   . o   m nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXaXW.5.c.AXNXI.@.f.y.u.i.w.6.p.u.u.t.h.c   X . .   2 .   . o   M nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXbXS.y.fXkXVXI.%.l.s.s.f.y.0.g.s.d.a.x.x           ,           b nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXLXUXvXgXCXU.[ 7.2.2.3.,.-.4.2.2.1.8.m $ > ; : ; w : ; ; , + D bXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXXXU.eXzXNX!.1 X @ + o = 1 X + + O # 7 $ & % & % 9 & % % =   Z bXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXcXuXZ p.tXlXNX~.:         # :         X ,           <           n nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXxXaX+.:.&XbXNX~.>   X .   $ >   .     o 1   .   .   2 .     o   m nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXpX.Xt.d.DXmX~.>   . .   $ >   . .   o 1   .   .   2 .   . o   m nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXvXf.&.wXzXNX~.;         @ :         o <           1 .     X   m nXkXlXlX",
"lXlXlXkXzXxXlXlXlXlXlXlXlXVXAXvXhXBX!.4 # & & $ , >         X 6 $ & % % % 5       X   m nXkXlXlX",
"lXlXkXcXhXsXzXlXlXlXlXlXzXlXyXlXhXBX!.7 - : : : & T.uX5X7X5XuXW o , ; , . ..aX5X8X7XqX}.pXxXlXlX",
"lXlXlXxX~ n.DXhXlXlXlXjXCXp.} ZXfXBX~.;           1XUXUXUXUXUX^   .   .   =.UXUXUXUXUXrXtXcXlXlX",
"lXlXkXNXx.z.DXhXlXlXlXkXnXXX&.MXgXBX~.>   X . X   *XUXJXPXJXUX~   O . O   &.UXHXPXKXUX6XyXcXlXlX",
"lXlXhXFXJ.h.FXhXlXlXlXkXnX6X$.MXgXBX~.>   .   .   =XUXLXUXLXUX~   o   O   &.UXKXUXPXUX7XyXcXlXlX",
"lXlXjXCXE.A.AXhXlXlXlXkXbX5Xe.mXgXBX~.>   X . X   =XUXPXUXPXUX!   X   o   %.UXJXPXLXUX7XyXcXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXjXBX~.=           *XUXKXIXKXUX/   $ O $   :.UXUXUXUXUXeXtXcXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXzXNXlXhXVXY.E O. . .X.[ w.v.l.l.k.m.S * 2 < 1 : x K F G H C  .zXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXxXdXW 2XcXVXI.*.c.g.h.j.a.5.y.r.r.e.d.z           ;           k mXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXhXZXU.s <XbXVXI.+.d.y.y.i.q.8.s.i.p.u.j.c   X . .   3 O o o +   N nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXxXuX! L ].MXBXI.@.g.u.i.p.e.7.a.i.i.y.j.c   X       2 .     X   m nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXaX).T '.MXBXU.$.j.p.p.s.t.9.d.p.a.i.k.n   + O O o 5 O o O @   B nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXzXSXgXjXjXZXH.{ u.0.q.w.5.,.e.0.q.9.p.i           +           f nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXxXzXjXmX+Xc.H.D.D.D.A.C.F.D.D.S.H.y.;.,.,.,.>.6.,.>.,.<.*.g.xXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXkXbXNXmXmXmXmXMXMXmXmXmXmXmXZXDXDXDXDXDXSXDXDXDXDXFXCXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXhXgXgXgXgXgXhXgXgXgXgXgXhXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXkXlXlXkXlXkXlXlXlXlXjXlXlXlXkXlXkXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXvXkXbXkXkXvXzXvXxXlXlXlXMXzXlXkXcXxXxXvXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXN.#.;XnXcX8X%.s.zXlXjXCX@.'.BXlXdX5.4.iXcXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXpX .].VXlXsX3XO.fXlXMX&Xm `.CXkXsXuX$.<XmXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjX,X6.H.AXhXvX:.W.VXfXVXy.x Z.SXfXBXp.c.CXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXB.<.1XvXnX:X^ B.kXlXkXjXC.[.NXzXiX{ p.iXxXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXDXmXkXlXcXPXmXkXlXlXvXHXbXkXlXlXKXVXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxX&XiXxXlXlX~.<XbXkXxXsXOXjXlXkXcX|.@XvXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXqXp 1XbXbX<Xt.O.sXlXMX XJ gXzXzXsXp._ 0XvXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXr.U :XMXgXZX2Xu.bXkXkXcX6.yXcXkXvXlX..qXvXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXv.B '.BXcX8Xv Y.bXkXlXxX-.yXxXcXeXj.O.=XMXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXDX4XpXxXcXwXP.).kXlXlXlX-XhXzXkXcX_.{.bXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXgXvXzXkXkXcXAXBXlXkXkXkXnXlXkXkXkXVXBXjXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXvXvXxXcXcXcXcXlXzXvXcXxXxXlXxXxXxXxXlXlXxXxXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXcXzXlXzXaXrXrXrXrXtXtXrXrXrXrXyXdXdXdXdXdXsXdXdXdXdXdXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXrXgXlXbXw.X.*.&.&.$.#.&.&.%.=. .S D D D F K S D F Z T tXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXnX<.7.eXcXvX7.9.s.i.a.r.8.a.i.u.h.O.          *         > yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXnX+.<.9XvXcX9.9.a.i.p.e.8.a.i.u.g.+.  X X . O <   X o   5 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXXX7.m.DXzX8.8.p.u.i.e.8.p.u.y.f.+.  . .   o ,   . X   4 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXjXmXK.<.qXcXcX9.w.f.s.d.y.q.f.s.a.l.#.          :         2 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXFXUXnXjXbX7.;.7.5.6.1.:.6.4.4.0.| & - - = : 9 * - ; $ r tXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXcX+XI.eXxXmX=.  # @ O = 1 O # # O 3 ; $ % $ = 6 $ & & O q yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXMXT 1.dXlXmX=.        + -         ; o       . :         2 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXxXZ.5._.NXnX=.  X .   # :   . .   > +   .   o ,   . X   4 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXcXR.&.U.CXbX=.  . .   # , X O O X < +       o 1 X O +   7 yXcXkXlX",
"lXlXlXlXhXkXlXlXlXlXkXbX=XQ.cXjXMX=.  .     # X         + @       O #         $ yXcXkXlX",
"lXlXlXlXZXbXkXlXlXlXlXjXSXPXkXkXMX;.* 1 < < < o.4.<.<.5.{ : < < 1 - / 6.<.1.1.<.eXvXkXlX",
"lXlXkXnXi._.VXjXlXlXjXNX_.r.MXhXMX=.  . . X   7XUXUXUXUX+X  o   O   R.UXUXUXUXMX9XvXkXlX",
"lXlXkXNX8.B.DXhXlXlXkXMX[.X.mXhXMX=.  .   .   &XUXGXGXUX).  X   o   D.UXFXJXUXpX9XvXkXlX",
"lXlXhXDXY.B.DXhXlXlXlXcXaX1.cXjXMX=.  X . X   =XUXKXKXUX`.  o   O   G.UXJXPXUXdX9XvXkXlX",
"lXlXjXVX~.R.CXjXlXlXlXcXtXf.cXjXMX=.          :XUXUXUXUX[.  .   X   H.UXIXUXUXhX9XvXkXlX",
"lXlXlXlXzXxXlXlXlXlXlXlXkXnXzXjXMX=.  + O +   oXLXMXmXIX!.  * $ =   A.UXVXAXKXtX9XvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXcXeXfXlXbX6.*.3.1.2.>.6.p.y.t.d.@.& ; - - ; u 0 0 q 6 j tXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXvXaXx >XnXcX9.e.g.s.f.u.8.p.u.y.g.+.        . -         , yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXjXBXc.K >XmXcX8.8.p.u.i.w.8.a.i.u.g.+.  . .   o <   X o   5 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXy.c (.VXxX9.0.s.i.a.r.9.a.i.u.h.@.  o o X @ 1 . o O   6 yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXZXXXqXcXvX3.5.u.r.y.0.4.u.r.e.d. .          @         * tXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXmXcXkXvXx.s.z.k.l.h.d.z.k.k.c.0.S G G F H T F G H A ! iXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXcXzXlXlXlXzXzXlXlXlXlXcXBXBXBXBXNXMXBXBXNXBXMXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkXlXlXzXlXlXlXlXkXlXlXlXzXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXzXhXcXkXxXgXzXxXkXzXbXlXlXzXfXvXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXcXiX4.).NXzXC.s.xXlXzX1.rXmXrXq.E.BXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXmXD.b.ZXcX&Xz.xXBXT.V qXvXnXJ.Q.VXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXvXwX7.E.MXnX-.V.mXcX&X<.5XVX7X( -XnXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXkXMXkXkXcXjXlXjXZXGXkXlXlXxXhXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXVX}.$XmXcXT.~.cXbX2XI.bXzXaXV.>XbXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXzXlXW I.ZXkX#Xq.lXnX<X5.nXjXbXl.m.AXhXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXnX5X^ G.CXmXr.Z.BXlXfXk.xXxXpXa.B.CXhXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXbXpXwXcXlX].@XzXlXhX5XlXzXfX[.tXxXkXlX",
"lXlXlXlXlXlXlXlXkXkXlXlXzXlXcXbXlXzXCXNXzXlXlXvXkXkXlXBXxXkXlXlX",
"lXlXlXlXlXlXlXlXxXbXlXlXkXgXfXfXgXgXdXdXfXxXvXcXvXcXvXxXvXcXlXlX",
"lXlXlXlXlXlXlXzXsX8XhXmXc.,.8.7.4.5.6.6.8._ P Y Y Q Y T P _ pXcX",
"lXlXlXlXlXlXhXZXq.e.bXnXi.8.i.i.9.q.u.t.d.9       O       ; iXcX",
"lXlXlXlXlXlXjXnXE.1.5XCXs.9.p.i.0.e.i.y.d.i   O X > O O   7 iXcX",
"lXlXlXlXlXlXkXnX Xi.uXNXd.u.j.j.u.a.j.g.x.u       =       3 iXcX",
"lXlXlXlXlXlXlXkXMXmXlXmXt.` o.X.|  .X...@.p $ ; = 6 - ; # t iXcX",
"lXlXlXlXlXlXjXBXC.b.lXCX:.      @ X       - X O X > O O   7 iXcX",
"lXlXlXlXlXlXjXBXx.6.uXAX>.  O   * $   . @ =       - . .   4 iXcX",
"lXlXjXlXlXlXjXnX X-.4XFX:.  .   % +     o *       =       3 iXcX",
"lXlXNXxXlXlXlXxXuXeXzXBX,.  & @ > * o O $ < @ $ # 1 + @   8 iXcX",
"lXxX.XiXxXlXkXvXqX-XxXBX<.  - O t 0XaXyXgXV   :   | vXrXdX<XrXcX",
"kXnX2.*XMXkXjXBX[.0.BXNX:.  X   9 PXUXUXUXV   +   #.UXUXUXmXrXvX",
"hXAXA.#XNXkXlXvXeXk.nXNX>.  @   q CXIXJXUXB   @   O.UXSXIXgXrXvX",
"kXbX-XeXcXkXlXxXpX&XzXVX;.      4 LXUXUXUXZ   $   *.UXUXUXZXrXvX",
"lXkXnXcXkXlXlXkXcXxXhXNXw.I / Q _ S.L.H.U.c @ > $ b #... .#.uXcX",
"lXlXkXkXlXlXkXbXwXo.hXmXf.i.l.l.u.7.w.0.y.t   .   $       % iXcX",
"lXlXlXlXlXlXhXCXx.H aXNXs.8.i.i.0.y.s.p.h.p   + X , $ # . 0 iXcX",
"lXlXlXlXlXlXkXcX>Xd.yXNXu.6.u.y.8.0.y.r.s.7       o       = iXcX",
"lXlXlXlXlXlXlXkXmXBXlXbXB.s.x.z.g.h.z.l.v.Q v B M G B B b U aXxX",
"lXlXlXlXlXlXlXlXkXjXlXlXzXkXkXkXlXlXkXkXkXbXMXmXmXmXmXmXMXnXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXkXjXjXjXkXlXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXzXdXlXzXgXdXxXkXvXlXzXdXhXxXlX",
"lXlXlXlXlXlXlXlXkXMXQ.H.ZX9Xl.tXSXA.`.DX*Xv.zXlX",
"lXlXlXlXlXlXlXlXkXmX~.f.DX1Xr.hXbX .L.LX[.h.mXkX",
"lXlXlXlXlXlXlXlXlXcX;X9XmX8X+XxXzXdXeXMX:X-XcXkX",
"lXlXlXlXlXlXlXlXkXbXtX&XNXrX_.fXbX XuXmX4X}.cXkX",
"lXlXlXlXlXlXlXlXjXAX0.e.JX0Xy.tXAXm.*XZX>X4.kXzX",
"lXlXlXlXlXlXlXlXkXvX`.Q.AX$Xx.zXnX$X6XBX#XS.zXlX",
"lXlXlXlXlXlXjXkXlXcXAXVXcXnXMXvXcXnXbXxXvXMXcXlX",
"lXlXlXlXlXzXBXzXlXeX6X7X0X9X8X9XyXuXuXuXuXyXiXkX",
"lXlXlXlXzXfX~.aXhX6.2.5.<.3.5.4.z e u f u q M uX",
"lXlXlXkXcXuX$.&XzX8.u.p.q.y.p.i.:     +     2 yX",
"lXlXlXlXlXzXZ.@XzXe.j.l.p.g.k.j.4   X = o   9 uX",
"lXlXlXlXlXlXyXzXjXo.I E E R R W 6 $ * 2 = + y uX",
"lXlXlXkXcXyX,.5XMXm     o       $   . = o   9 uX",
"lXjXlXlXzXjXq._.ZXV   X &     o #     $     4 uX",
"zXNXlXlXlXzX5XaXvXD   # < 2 > 3 : + @ 3 1 * d uX",
"hX~.gXzXkXxX'.aXvXS     L DXnXzXi o   ,.LXnXiXyX",
"vXl.yXcXjXNXx.2XNXC     I UXUXPXr     3.UXUXmXyX",
"bX@XsXxXkXbX*XyXnXM     H UXUXUXu     0.UXUXGXyX",
"kXbXzXlXkXcXgXdXjX+.Q Q @.U.P.K.r # @ n @.] %.yX",
"lXkXlXlXjXNX<.{.vXr.j.z.y.9.w.q.3   o @     ; uX",
"lXlXlXlXzXjX<.|.cX4.w.r.7.t.u.y.*     X     1 yX",
"lXlXlXlXlXxXcXjXgXk.z.c.h.l.x.x.G l v V b k P pX",
"lXlXlXlXlXlXkXzXlXkXjXjXjXjXjXjXcXbXbXvXbXbXvXlX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXjXhXlXfXlXcXlXgXjXlX",
"lXlXlXlXlXxXuXG.lXK.zXC.eX{.*XMX",
"lXlXlXlXlXzXdX-XhXXXxX$XdX*XeXvX",
"lXlXlXlXlXxXuXT.xX/.hX+XkXOX-XmX",
"lXlXlXlXjXcXuX^.zX^.cX:XkX@X,XmX",
"lXlXlXlXmXlXgXlXpXfXdXcXkXxXxXkX",
"lXlXlXkX_.sXj.0.w.a.X.y z p C yX",
"lXlXlXxXL.0Xx.f.i.m.(   X   : rX",
"lXkXlXkX%XlX] s M N d + > % y tX",
"zXcXlXzXm.pXB         X X   @ rX",
"hXtXzXzX5XxXK   I p.E   y 3.8.uX",
"aX(.cXcX(.lXA   n.UXE.  D UXUXsX",
"lXpXlXxXiXzX` 2 r.jXy.  l ).Q.iX",
"lXxXkXbXm.7Xl.s.7.r.U       X rX",
"lXkXlXzX-XpXm.g.g.B.&.q k p C uX",
"lXlXlXlXmXxXgXfXgXfXgXjXjXjXjXlX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
